@@ -76,6 +76,7 @@ EXPORT	int	scsi_prevent_removal __PR((SCSI *scgp, int));
 EXPORT	int	scsi_start_stop_unit __PR((SCSI *scgp, int, int));
 EXPORT	int	scsi_set_speed	__PR((SCSI *scgp, int readspeed, int writespeed));
 EXPORT	int	scsi_get_speed	__PR((SCSI *scgp, int *readspeedp, int *writespeedp));
+EXPORT	int	scsi_set_streaming __PR((SCSI *scgp, int readspeed, int writespeed));
 EXPORT	int	qic02		__PR((SCSI *scgp, int));
 EXPORT	int	write_xg0	__PR((SCSI *scgp, caddr_t, long, long, int));
 EXPORT	int	write_xg1	__PR((SCSI *scgp, caddr_t, long, long, int));
@@ -459,6 +460,36 @@ EXPORT int scsi_get_speed(SCSI *scgp, int *readspeedp, int *writespeedp)
 	return (0);
 }
 
+EXPORT int scsi_set_streaming(SCSI *scgp, int readspeed, int writespeed)
+{
+	register struct	scg_cmd	*scmd = scgp->scmd;
+	char pdesc[28];
+
+	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	fillbytes((caddr_t)pdesc, sizeof(pdesc), '\0');
+	scmd->addr = pdesc;
+	scmd->size = sizeof(pdesc);
+	scmd->flags = SCG_DISRE_ENA;
+	scmd->cdb_len = SC_G5_CDBLEN;
+	scmd->sense_len = CCS_SENSE_LEN;
+	scmd->cdb.g5_cdb.cmd = 0xB6;
+	scmd->cdb.g5_cdb.lun = scg_lun(scgp);
+	i_to_2_byte(&scmd->cdb.g5_cdb.addr[7], sizeof(pdesc));
+
+	i_to_4_byte(&pdesc[4], 0);
+	i_to_4_byte(&pdesc[8], scgp->cap->c_baddr);
+	i_to_4_byte(&pdesc[12], readspeed);
+	i_to_4_byte(&pdesc[16], 1000);	/* read time (ms) */
+	i_to_4_byte(&pdesc[20], writespeed);
+	i_to_4_byte(&pdesc[24], 1000);	/* read time (ms) */
+
+	scgp->cmdname = "set streaming";
+
+	if (scg_cmd(scgp) < 0)
+		return (-1);
+	return (0);
+}
+
 
 EXPORT int qic02(SCSI *scgp, int cmd)
 {
