@@ -228,7 +228,7 @@ scgo_ropen(scgp, device)
 	if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN) {
 		errno = EINVAL;
 		if (scgp->errstr)
-		    js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+		    snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 		       "Illegal value for busno, target or lun '%d,%d,%d'",
 		       busno, tgt, tlun);
 
@@ -252,7 +252,7 @@ scgo_ropen(scgp, device)
 	if (device == NULL || (strncmp(device, "REMOTE", 6) != 0) ||
 				(device = strchr(device, ':')) == NULL) {
 		if (scgp->errstr)
-		    js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+		    snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 		       "Illegal remote device syntax");
 		return (-1);
 	}
@@ -260,7 +260,7 @@ scgo_ropen(scgp, device)
 	/*
 	 * Save non user@host:device
 	 */
-	js_snprintf(devname, sizeof(devname), device);
+	snprintf(devname, sizeof(devname), device);
 
 	if ((p = strchr(devname, ':')) != NULL)
 		*p++ = '\0';
@@ -268,7 +268,7 @@ scgo_ropen(scgp, device)
 	f = rscsigetconn(scgp, devname);
 	if (f < 0) {
 		if (scgp->errstr)
-		    js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+		    snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 		       "Cannot get connection to remote host");
 		return (-1);
 	}
@@ -488,7 +488,7 @@ rscsigetconn(scgp, host)
 		}
 	}
 	if ((p = strchr(host, '@')) != NULL) {
-		js_snprintf(rscsiuser, sizeof(rscsiuser), "%.*s", p - host, host);
+		snprintf(rscsiuser, sizeof(rscsiuser), "%.*s", p - host, host);
 		name = rscsiuser;
 		host = &p[1];
 	} else {
@@ -515,7 +515,7 @@ rscsiversion(scgp, fd, what)
 	char	*p;
 	int	ret;
 
-	js_snprintf(cbuf, sizeof(cbuf), "V%d\n", what);
+	snprintf(cbuf, sizeof(cbuf), "V%d\n", what);
 	ret = rscsicmd(scgp, fd, "version", cbuf);
 	p = malloc(ret);
 	if (p == NULL)
@@ -537,7 +537,7 @@ rscsiopen(scgp, fd, fname)
 	int	tgt;
 	int	lun;
 
-	js_snprintf(cbuf, sizeof(cbuf), "O%s\n", fname?fname:"");
+	snprintf(cbuf, sizeof(cbuf), "O%s\n", fname?fname:"");
 	ret = rscsicmd(scgp, fd, "open", cbuf);
 	if (ret < 0)
 		return (ret);
@@ -567,7 +567,7 @@ rscsimaxdma(scgp, fd, amt)
 {
 	char	cbuf[CMD_SIZE];
 
-	js_snprintf(cbuf, sizeof(cbuf), "D%ld\n", amt);
+	snprintf(cbuf, sizeof(cbuf), "D%ld\n", amt);
 	return (rscsicmd(scgp, fd, "maxdma", cbuf));
 }
 
@@ -581,7 +581,7 @@ rscsigetbuf(scgp, fd, amt)
 	int	size;
 	int	ret;
 
-	js_snprintf(cbuf, sizeof(cbuf), "M%ld\n", amt);
+	snprintf(cbuf, sizeof(cbuf), "M%ld\n", amt);
 	ret = rscsicmd(scgp, fd, "getbuf", cbuf);
 	if (ret < 0)
 		return (ret);
@@ -631,7 +631,7 @@ rscsihavebus(scgp, fd, busno)
 {
 	char	cbuf[2*CMD_SIZE];
 
-	js_snprintf(cbuf, sizeof(cbuf), "B%d\n%d\n",
+	snprintf(cbuf, sizeof(cbuf), "B%d\n%d\n",
 		busno,
 		0);
 	return (rscsicmd(scgp, fd, "havebus", cbuf));
@@ -647,7 +647,7 @@ rscsifileno(scgp, fd, busno, tgt, tlun)
 {
 	char	cbuf[3*CMD_SIZE];
 
-	js_snprintf(cbuf, sizeof(cbuf), "T%d\n%d\n%d\n%d\n",
+	snprintf(cbuf, sizeof(cbuf), "T%d\n%d\n%d\n%d\n",
 		busno,
 		0,
 		tgt,
@@ -679,7 +679,7 @@ rscsireset(scgp, fd, what)
 {
 	char	cbuf[CMD_SIZE];
 
-	js_snprintf(cbuf, sizeof(cbuf), "R%d\n", what);
+	snprintf(cbuf, sizeof(cbuf), "R%d\n", what);
 	return (rscsicmd(scgp, fd, "reset", cbuf));
 }
 
@@ -694,7 +694,7 @@ rscsiscmd(scgp, fd, sp)
 	int	amt = 0;
 	int	voidsize = 0;
 
-	ret = js_snprintf(cbuf, sizeof(cbuf), "S%d\n%d\n%d\n%d\n%d\n",
+	ret = snprintf(cbuf, sizeof(cbuf), "S%d\n%d\n%d\n%d\n%d\n",
 		sp->size, sp->flags,
 		sp->cdb_len, sp->sense_len,
 		sp->timeout);
