@@ -35,7 +35,7 @@ _nixread(f, buf, count)
  
 	while(count > 0) {
 		while((ret = read(f, p, count)) < 0) {
-			if (geterrno() == EINTR)
+			if (errno == EINTR)
 				continue;
 			return (ret);	/* Any other error */
 		}
